|buildstatus|_
|coverage|_

About
=====

`PIC tools` is a collection of tools to ease PIC software
development. PIC is family of microcontrollers made by `Microchip`_.

Features:

- A PIC programmer based on an `Arduino Due`_. Today only the
  `PIC32MM0256GPM064`_ family is supported.

Project homepage: https://github.com/eerimoq/pictools

Documentation: http://pictools.readthedocs.org/en/latest

.. |buildstatus| image:: https://travis-ci.org/eerimoq/pictools.svg?branch=master
.. _buildstatus: https://travis-ci.org/eerimoq/pictools

.. |coverage| image:: https://coveralls.io/repos/github/eerimoq/pictools/badge.svg?branch=master
.. _coverage: https://coveralls.io/github/eerimoq/pictools

.. _Arduino Due: https://store.arduino.cc/arduino-due

.. _Microchip: https://www.microchip.com/

.. _PIC32MM0256GPM064: https://www.microchip.com/wwwproducts/en/PIC32MM0256GPM064
